aboutsummaryrefslogtreecommitdiffstats
path: root/java/src/com/android/inputmethod/latin/LatinIME.java
diff options
context:
space:
mode:
authorTadashi G. Takaoka <takaoka@google.com>2013-11-21 09:05:38 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2013-11-21 09:05:39 +0000
commitafb95c79677d50b05f0b034dba16ccb522750c1c (patch)
treeda4cfaf3810dce711414cfc0622c1f2250259fe8 /java/src/com/android/inputmethod/latin/LatinIME.java
parent9882fbb2eef81158e2d789e624d56d12b844f991 (diff)
parent42d9980a84fa8f639638269a8498aa54e85b2eb4 (diff)
downloadlatinime-afb95c79677d50b05f0b034dba16ccb522750c1c.tar.gz
latinime-afb95c79677d50b05f0b034dba16ccb522750c1c.tar.xz
latinime-afb95c79677d50b05f0b034dba16ccb522750c1c.zip
Merge "Rename ambiguous feature name and related resources"
Diffstat (limited to 'java/src/com/android/inputmethod/latin/LatinIME.java')
-rw-r--r--java/src/com/android/inputmethod/latin/LatinIME.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/java/src/com/android/inputmethod/latin/LatinIME.java b/java/src/com/android/inputmethod/latin/LatinIME.java
index 955b83556..842c658e1 100644
--- a/java/src/com/android/inputmethod/latin/LatinIME.java
+++ b/java/src/com/android/inputmethod/latin/LatinIME.java
@@ -3081,8 +3081,8 @@ public class LatinIME extends InputMethodService implements KeyboardActionListen
private void hapticAndAudioFeedback(final int code, final int repeatCount) {
final MainKeyboardView keyboardView = mKeyboardSwitcher.getMainKeyboardView();
- if (keyboardView != null && keyboardView.isInSlidingKeyInput()) {
- // No need to feedback while sliding input.
+ if (keyboardView != null && keyboardView.isInDraggingFinger()) {
+ // No need to feedback while finger is dragging.
return;
}
if (repeatCount > 0) {